@@ -71,10 +71,10 @@ def find_font(font_name, weight='normal', style='normal'):
     return _fonts_find_font(font_name, weight, style)
 
 
-__version__ = '1.4.0'
+__version__ = '1.5.0'
 __license__ = 'LGPL 3'
 __author__ = 'Dinu Gherman'
-__date__ = '2022-08-05'
+__date__ = '2023-01-05'
 
 XML_NS = 'http://www.w3.org/XML/1998/namespace'
 
@@ -133,7 +133,7 @@ class CSSMatcher(cssselect2.Matcher):
         )
 
         for rule in rules:
-            if not rule.prelude:
+            if not rule.prelude or rule.type == 'at-rule':
                 continue
             selectors = cssselect2.compile_selector_list(rule.prelude)
             selector_string = tinycss2.serialize(rule.prelude)
@@ -325,10 +325,14 @@ class Svg2RlgAttributeConverter(AttributeConverter):
             return float(text[:-2]) * em_base
         elif text.endswith("px"):
             return float(text[:-2])
-
-        if "ex" in text:
-            logger.warning("Ignoring unit ex")
-            text = text.replace("ex", '')
+        elif text.endswith("ex"):
+            # The x-height of the text must be assumed to be 0.5em tall when the
+            # text cannot be measured.
+            return float(text[:-2]) * em_base / 2
+        elif text.endswith("ch"):
+            # The advance measure of the "0" glyph must be assumed to be 0.5em
+            # wide when the text cannot be measured.
+            return float(text[:-2]) * em_base / 2
 
         text = text.strip()
         length = toLength(text)  # this does the default measurements such as mm and cm
@@ -681,7 +685,7 @@ class SvgRenderer:
             return None
 
         # First handle any raster embedded image data
-        match = re.match(r"^data:image/(jpeg|png);base64", xlink_href)
+        match = re.match(r"^data:image/(jpe?g|png);base64", xlink_href)
         if match:
             img_format = match.groups()[0]
             image_data = base64.decodebytes(xlink_href[(match.span(0)[1] + 1):].encode('ascii'))
@@ -1090,6 +1094,7 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
         unclosed_subpath_pointers = []
         subpath_start = []
         lastop = ''
+        last_quadratic_cp = None
 
         for i in range(0, len(normPath), 2):
             op, nums = normPath[i:i+2]
@@ -1167,16 +1172,19 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
                 (x0, y0), (x1, y1), (x2, y2), (xn, yn) = \
                     convert_quadratic_to_cubic_path((x0, y0), (x1, y1), (xn, yn))
                 path.curveTo(x1, y1, x2, y2, xn, yn)
+                last_quadratic_cp = (x1, y1)
             elif op == 'T':
-                if len(points) < 4:
-                    xp, yp, x0, y0 = points[-2:] * 2
+                if last_quadratic_cp is not None:
+                    xp, yp = last_quadratic_cp
                 else:
-                    xp, yp, x0, y0 = points[-4:]
+                    xp, yp = points[-2:]
+                x0, y0 = points[-2:]
                 xi, yi = x0 + (x0 - xp), y0 + (y0 - yp)
                 xn, yn = nums
                 (x0, y0), (x1, y1), (x2, y2), (xn, yn) = \
                     convert_quadratic_to_cubic_path((x0, y0), (xi, yi), (xn, yn))
                 path.curveTo(x1, y1, x2, y2, xn, yn)
+                last_quadratic_cp = (xi, yi)
 
             # quadratic bezier, relative
             elif op == 'q':
@@ -1186,11 +1194,12 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
                 (x0, y0), (x1, y1), (x2, y2), (xn, yn) = \
                     convert_quadratic_to_cubic_path((x0, y0), (x1, y1), (xn, yn))
                 path.curveTo(x1, y1, x2, y2, xn, yn)
+                last_quadratic_cp = (x1, y1)
             elif op == 't':
-                if len(points) < 4:
-                    xp, yp, x0, y0 = points[-2:] * 2
+                if last_quadratic_cp is not None:
+                    xp, yp = last_quadratic_cp
                 else:
-                    xp, yp, x0, y0 = points[-4:]
+                    xp, yp = points[-2:]
                 x0, y0 = points[-2:]
                 xn, yn = nums
                 xn, yn = x0 + xn, y0 + yn
@@ -1198,6 +1207,7 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
                 (x0, y0), (x1, y1), (x2, y2), (xn, yn) = \
                     convert_quadratic_to_cubic_path((x0, y0), (xi, yi), (xn, yn))
                 path.curveTo(x1, y1, x2, y2, xn, yn)
+                last_quadratic_cp = (xi, yi)
 
             # elliptical arc
             elif op in ('A', 'a'):
@@ -1219,6 +1229,9 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
 
             else:
                 logger.debug("Suspicious path operator: %s", op)
+
+            if op not in ('Q', 'q', 'T', 't'):
+                last_quadratic_cp = None
             lastop = op
 
         gr = Group()
@@ -1324,19 +1337,7 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
             (["font-size"], "fontSize", "convertLength", [str(DEFAULT_FONT_SIZE)]),
             (["text-anchor"], "textAnchor", "id", ["start"]),
         )
-        """
-        font-style: italic;
-        font-weight: bold;
-        font-size: .8em;
-        line-height: 1.2;
-        font-family: Arial, sans-serif;
 
-        ... can be shortened to the following:
-
-        font: italic bold .8em/1.2 Arial, sans-serif;
-        """
-
-        import pdb; pdb.set_trace()
         if shape.__class__ == Group:
             # Recursively apply style on Group subelements
             for subshape in shape.contents:
